/*******************************************************************************
 transcode_process.h

 Copyright (C) 2016-2020 CodeShop B.V.
 http://www.code-shop.com

 For licensing see the LICENSE file
*******************************************************************************/

#ifndef TRANSCODE_PROCESS_H_AKW
#define TRANSCODE_PROCESS_H_AKW

#include "mod_streaming_export.h"
#include "streaming_io.h"

#ifdef __cplusplus
extern "C" {
#endif

struct mp4_process_context_t;

/*
 * URL-based transcoding interface for handling GET requests.
 * It expects context->pipeline_config_ to contain a serialized
 * pipeline_config_t, and takes its input from the URL in the embedded
 * url_decoder_config_t.
 * This function reports its output by repeatingly calling writer.
 */
MP4_DLL_EXPORT int transcode_process(
  struct mp4_process_context_t* context,
  streaming_writer_t writer, void* writer_arg);

/*
 * Streaming-based transcoding interface for handling (long-running)
 * POST requests.
 * It expects context->pipeline_config_ to contain a serialized
 * streaming_pipeline_config_t.
 * This funtion obtains its input by repeatingly calling reader,
 * and reports its output by repeatingly calling writer.
 */
MP4_DLL_EXPORT int transcode_process_streaming(
  struct mp4_process_context_t* context,
  streaming_reader_t reader, void* reader_arg,
  streaming_writer_t writer, void* writer_arg);

// Returns a fixed 0-terminated prefix for a pipeline config.
MP4_DLL_EXPORT char const *pipeline_config_prefix(void);

#ifdef __cplusplus
} /* extern C definitions */
#endif

#endif // TRANSCODE_PROCESS_H_AKW

// End Of File

